<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-images?lang_cible=br
// ** ne pas modifier le fichier **

return [

	// I
	'images_description' => 'Siloù treuzfurmadur skeudennoù ha livioù',
	'images_slogan' => 'Siloù treuzfurmadur skeudennoù ha livioù',
];
